@@ -3,10 +3,10 @@ use warnings;
 
 package Dist::Zilla::Plugin::Doppelgaenger;
 # ABSTRACT: Creates an evil twin of a CPAN distribution
-our $VERSION = '0.007'; # VERSION
+
+our $VERSION = '0.008'; # from Dist-Zilla-Plugin-Doppelgaenger-0.008.tar.gz
 
 use Moose;
-use Moose::Autobox;
 use MooseX::Types::Path::Class qw(Dir File);
 use MooseX::Types::URI qw(Uri);
 use MooseX::Types::Perl qw(ModuleName);
@@ -30,11 +30,11 @@ use namespace::autoclean;
 # public attributes
 #--------------------------------------------------------------------------#
 
-# =attr source_module (REQUIRED)
-#
-# The name of a CPAN module to imitate.  E.g. Foo::Bar
-#
-# =cut
+#pod =attr source_module (REQUIRED)
+#pod
+#pod The name of a CPAN module to imitate.  E.g. Foo::Bar
+#pod
+#pod =cut
 
 has source_module => (
     is       => 'ro',
@@ -42,12 +42,12 @@ has source_module => (
     required => 1,
 );
 
-# =attr new_name
-#
-# The new name to use in place of the source name.  Defaults to
-# the converted form of the distribution name.
-#
-# =cut
+#pod =attr new_name
+#pod
+#pod The new name to use in place of the source name.  Defaults to
+#pod the converted form of the distribution name.
+#pod
+#pod =cut
 
 has new_name => (
     is       => 'ro',
@@ -64,12 +64,12 @@ sub _build_new_name {
     return $name;
 }
 
-# =attr cpan_mirror
-#
-# This is a URI to a CPAN mirror.  It must be an 'http' URI.
-# Defaults to C<http://www.cpan.org/>
-#
-# =cut
+#pod =attr cpan_mirror
+#pod
+#pod This is a URI to a CPAN mirror.  It must be an 'http' URI.
+#pod Defaults to C<http://www.cpan.org/>
+#pod
+#pod =cut
 
 has cpan_mirror => (
     is      => 'ro',
@@ -78,14 +78,14 @@ has cpan_mirror => (
     default => 'http://www.cpan.org/'
 );
 
-# =attr strip_version
-#
-# Boolean for whether any assignments to C<$VERSION> should be stripped out of
-# the source.  This is a crude hack and acts by killing a line of code containing
-# such assignments.  This obviously may not work in all cases and should be used
-# with caution.  Default is false.
-#
-# =cut
+#pod =attr strip_version
+#pod
+#pod Boolean for whether any assignments to C<$VERSION> should be stripped out of
+#pod the source.  This is a crude hack and acts by killing a line of code containing
+#pod such assignments.  This obviously may not work in all cases and should be used
+#pod with caution.  Default is false.
+#pod
+#pod =cut
 
 has strip_version => (
     is      => 'ro',
@@ -93,13 +93,13 @@ has strip_version => (
     default => 0,
 );
 
-# =attr strip_pod
-#
-# Boolean for whether Pod should be stripped when copying from source.
-# Default is false.
-#
-#
-# =cut
+#pod =attr strip_pod
+#pod
+#pod Boolean for whether Pod should be stripped when copying from source.
+#pod Default is false.
+#pod
+#pod
+#pod =cut
 
 has strip_pod => (
     is      => 'ro',
@@ -107,11 +107,11 @@ has strip_pod => (
     default => 0,
 );
 
-# =attr changes_file
-#
-# Name of change log file.  Defaults to 'Changes'.
-#
-# =cut
+#pod =attr changes_file
+#pod
+#pod Name of change log file.  Defaults to 'Changes'.
+#pod
+#pod =cut
 
 has changes_file => (
     is      => 'ro',
@@ -119,12 +119,12 @@ has changes_file => (
     default => 'Changes',
 );
 
-# =attr update_changes_file
-#
-# Boolean for whether change log should be updated with the
-# source distribution when built. Default is true.
-#
-# =cut
+#pod =attr update_changes_file
+#pod
+#pod Boolean for whether change log should be updated with the
+#pod source distribution when built. Default is true.
+#pod
+#pod =cut
 
 has update_changes_file => (
     is      => 'ro',
@@ -134,12 +134,12 @@ has update_changes_file => (
 
 sub mvp_multivalue_args { qw(exclude_filename exclude_match) }
 
-# =attr exclude_filename
-#
-# To exclude certain files from being gathered, use the C<exclude_filename>
-# option. This may be used multiple times to specify multiple files to exclude.
-#
-# =cut
+#pod =attr exclude_filename
+#pod
+#pod To exclude certain files from being gathered, use the C<exclude_filename>
+#pod option. This may be used multiple times to specify multiple files to exclude.
+#pod
+#pod =cut
 
 has exclude_filename => (
     is      => 'ro',
@@ -147,13 +147,13 @@ has exclude_filename => (
     default => sub { [] },
 );
 
-# =attr exclude_match
-#
-# This is just like C<exclude_filename> but provides a regular expression
-# pattern.  Files matching the pattern are not gathered.  This may be used
-# multiple times to specify multiple patterns to exclude.
-#
-# =cut
+#pod =attr exclude_match
+#pod
+#pod This is just like C<exclude_filename> but provides a regular expression
+#pod pattern.  Files matching the pattern are not gathered.  This may be used
+#pod multiple times to specify multiple patterns to exclude.
+#pod
+#pod =cut
 
 has exclude_match => (
     is      => 'ro',
@@ -233,9 +233,9 @@ sub gather_files {
       unless $extracted;
 
     my $exclude_regex = qr/\000/;
-    $exclude_regex = qr/$exclude_regex|$_/ for ( $self->exclude_match->flatten );
+    $exclude_regex = qr/$exclude_regex|$_/ for ( @{ $self->exclude_match } );
 
-    my %is_excluded = map { ; $_ => 1 } $self->exclude_filename->flatten;
+    my %is_excluded = map { ; $_ => 1 } @{ $self->exclude_filename };
 
     FILE: for my $filename ( grep { -f } @{ $ae->files } ) {
         my $file = file($filename)->relative($extracted);
@@ -335,9 +335,10 @@ sub _munge_changes {
     my $content  = $file->content;
     my $distfile = $self->_short_distfile;
     my $delim    = $self->delim;
+    my $url      = $self->_changes_url($distfile);
 
     $content =~ s{ (\Q$delim->[0]\E \s* \$NEXT \s* \Q$delim->[1]\E) }
-               {$1\n\n  - Generated from $distfile}xs;
+               {$1\n\n  - Generated from $distfile\n\n  - See $url for details}xs;
 
     $file->content($content);
 }
@@ -374,6 +375,15 @@ sub _download {
     return $tarball;
 }
 
+my $archive_re = qr{\.tar\.gz|\.tgz|\.zip|\.tar\.bz|\.tbz};
+
+sub _changes_url {
+    my ( $self, $distfile ) = @_;
+
+    $distfile =~ s{$archive_re$}{};
+    return "https://metacpan.org/changes/release/$distfile";
+}
+
 sub _file_from_filename {
     my ( $self, $filename, $rel_name ) = @_;
 
@@ -410,7 +420,7 @@ Dist::Zilla::Plugin::Doppelgaenger - Creates an evil twin of a CPAN distribution
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -435,6 +445,8 @@ your original Changes file might look something like this:
 
     - Generated from AUTHOR/Foo-Bar-1.23.tar.gz
 
+    - See https://metacpan.org/changes/release/AUTHOR/Foo-Bar-1.23 for details
+
 If you strip Pod, you may with to explore replacing it with new Pod using
 the L<Dist::Zilla::Plugin::AppendExternalData> plugin.
 
